@@ -73,6 +73,7 @@ def delta_analyze(element, configuration, V0, B0, B1, natoms) -> orm.Dict:
         - FCC
         - SC
         - Diamond
+    - For actinides and Ar, Fr, Ra: using FCC from ACWF dataset
 
     conf_key is key in json file for configurations of every element.
     """
@@ -93,11 +94,11 @@ def delta_analyze(element, configuration, V0, B0, B1, natoms) -> orm.Dict:
         conf_key = f"{element}"
 
     if configuration in UNARIE_CONFIGURATIONS:
-        ref_json = "WIEN2K_UNARIES.json"
+        ref_json = "AE-average-unaries.json"
         conf_key = f"{element}-X/{configuration}"
 
     if configuration in OXIDE_CONFIGURATIONS:
-        ref_json = "WIEN2K_OXIDES.json"
+        ref_json = "AE-average-oxides.json"
         conf_key = f"{element}-{configuration}"
 
     import_path = importlib.resources.path(
@@ -116,18 +117,23 @@ def delta_analyze(element, configuration, V0, B0, B1, natoms) -> orm.Dict:
     # Delta computation
     delta, deltarel, delta1 = _calcDelta(ref_V0, ref_B0, ref_B1, V0, B0, B1)
 
-    nu_measure = rel_errors_vec_length(
-        ref_V0,
-        ref_B0,
-        ref_B1,
-        V0,
-        B0,
-        B1,
-        config_string=None,
-        prefact=400,  # XXX: re-inspect this value and set it in protocol
-        weight_b0=1 / 8,
-        weight_b1=1 / 64,
-    )
+    # The nu_measure is a measure of the relative error of the fit
+    # It is not used as the output of the verification since the final formula not decided yet
+    # Please update and use the function from ACWF
+    # In the aiidalab-sssp the nu_measure is calculated in the app rather than read from output given by this calcfunction.
+
+    # nu_measure = rel_errors_vec_length(
+    #     ref_V0,
+    #     ref_B0,
+    #     ref_B1,
+    #     V0,
+    #     B0,
+    #     B1,
+    #     config_string=None,
+    #     prefact=1,
+    #     weight_b0=1 / 20,
+    #     weight_b1=1 / 400,
+    # )
 
     return orm.Dict(
         dict={
@@ -141,14 +147,21 @@ def delta_analyze(element, configuration, V0, B0, B1, natoms) -> orm.Dict:
             "birch_murnaghan_results": [V0, B0, B1],
             "reference_wien2k_V0_B0_B1": [ref_V0, ref_B0, ref_B1],
             "V0_B0_B1_units_info": "eV/A^3 for B0",
-            "rel_errors_vec_length": nu_measure,
-            "nu/natoms": nu_measure / natoms,
+            # "rel_errors_vec_length": nu_measure,
         }
     )
 
 
 def rel_errors_vec_length(
-    v0w, b0w, b1w, v0f, b0f, b1f, config_string, prefact, weight_b0, weight_b1
+    v0w,
+    b0w,
+    b1w,
+    v0f,
+    b0f,
+    b1f,
+    prefact=100,
+    weight_b0=1 / 20,
+    weight_b1=1 / 400,
 ):
     """
     Returns the length of the vector formed by the relative error of V0, B0, B1
