@@ -63,7 +63,7 @@ class _BaseConvergenceWorkChain(SelfCleanWorkChain):
     def define(cls, spec):
         super().define(spec)
         # yapf: disable
-        spec.input('code', valid_type=orm.Code,
+        spec.input('code', valid_type=orm.AbstractCode,
                     help='The `pw.x` code use for the `PwCalculation`.')
         spec.input('pseudo', valid_type=UpfData, required=True,
                     help='Pseudopotential to be verified')
@@ -185,7 +185,7 @@ class _BaseConvergenceWorkChain(SelfCleanWorkChain):
         in control.yml protocol file. Most likely run the 200vs300_ref_check
         protocol.
         """
-        return self._RUN_RHO_TEST and (self.ctx.dual_scan_list)
+        return self._RUN_RHO_TEST and len(self.ctx.dual_scan_list) > 0
 
     def init_setup(self):
         """
